### Transportation Electrification Load Profiles by Balancing Authority in the Western United States for GODEEEP

Time-series electric charging load profiles for the transportation sector across Balancing Authorities (BAs) in the Western Electricity Coordinating Council (WECC) interconnect for the years 2025, 2030, 2035, and 2050. The data is provided for two different socioeconomic pathways and two different climate pathways, resulting in four total scenarios. The socioeconomic pathways--Business-As-Usual with Climate (BAU\_Climate) and Net-Zero without CCS (NetZeroNoCCS\_Climate)--are described by [https://doi.org/10.5281/zenodo.7838871](https://doi.org/10.5281/zenodo.7838871). The climate pathways--Representative Concentration Pathway 4.5 cooler (rcp45cooler) and Representative Concentration Pathway 8.5 hotter (rcp85hotter)--are described by [https://doi.org/10.57931/1885756](https://doi.org/10.57931/1885756). The climate influence is only considered for Light Duty Vehicles (LDVs).

For additional details please consult the paper _Acharya et al 2023, Developing Spatio-Temporal Transportation Electric Load from Multi-Sector Dynamics Model, in prep_, and the code repository [https://github.com/GODEEEP/transportation_electrification](https://github.com/GODEEEP/transportation_electrification).

A brief summary of the files and directories in this data package is provided below. Text within chevrons implies a multiplicity of files, one for each actual value.

* BAU_Climate
	* rcp45cooler
		* \<balancing authority\>\_hourly\_transportation\_load\_\<socioeconomic pathway\>\_\<climate scenario\>\_\<year\>.csv
	* rcp85hotter
		* \<balancing authority\>\_hourly\_transportation\_load\_\<socioeconomic pathway\>\_\<climate scenario\>\_\<year\>.csv
* NetZeroNoCCS_Climate
	* rcp45cooler
		* \<balancing authority\>\_hourly\_transportation\_load\_\<socioeconomic pathway\>\_\<climate scenario\>\_\<year\>.csv
	* rcp85hotter
		* \<balancing authority\>\_hourly\_transportation\_load\_\<socioeconomic pathway\>\_\<climate scenario\>\_\<year\>.csv
* WECC\_hourly\_transportation\_load\_\<socioeconomic pathway\>\_\<climate scenario\>\_\<year\>.csv

Each file is in comma-separated-value (CSV) format with the following columns:

* `time` - ISO 8601 timestamp representing the end of the hourly timestep; values are reported as the summation over the preceding hour
* `balancing_authority` - Acronym of the balancing authority for this data point
* `LDV_load_MWh` - Energy consumed by the charging of Light Duty Vehicles (LDVs) during the previous hour in Megawatt hours
* `MDV_load_MWh` - Energy consumed by the charging of Medium Duty Vehicles (MDVs) during the previous hour in Megawatt hours
* `HDV_load_MWh` - Energy consumed by the charging of Heavy Duty Vehicles (HDVs) during the previous hour in Megawatt hours
* `passenger_rail_load_MWh` - Energy consumed by the charging of passenger rail vehicles during the previous hour in Megawatt hours
* `freight_rail_load_MWh` - Energy consumed by the charging of freight rail vehicles during the previous hour in Megawatt hours
* `aviation_load_MWh` - Energy consumed by the charging of aviation vehicles during the previous hour in Megawatt hours
* `ship_load_MWh` - Energy consumed by the charging of ships during the previous hour in Megawatt hours
* `transportation_load_MWh` - Total energy consumed by the charging of vehicles during the previous hour in Megawatt hours (summation of the other columns)

The WECC files provide summations of all BAs for each scenario, with the same columns excepting `balancing_authority`.
